==> motivational-numerology-2.3.2.tgz: package/README.md <==
# Motivational-Numerology [![npm version](https://img.shields.io/npm/v/motivational-numerology)](https://www.npmjs.com/package/motivational-numerology)

Motivational-Numerology is a web page to calculate the numerology numbers derived from your name and birth date and get a brief interpretation by [Sally Faubion](http://sallysnumbers.com/).

Check out [your numerology star](https://evoluteur.github.io/motivational-numerology/).

[![Star](https://raw.githubusercontent.com/evoluteur/motivational-numerology/master/pix/numerology-star-labels.gif)](https://evoluteur.github.io/motivational-numerology/)

To better understand your personal numerology numbers and go deeper in their interpretation, [book a private phone reading](https://sallysnumbers.com/services/) with Sally Faubion.

## Numerology Numbers

Your numerology numbers are calculated based on your birthdate and your full name.

Your **Destiny**, **Personality**, and **Attitude** derive from your **birth date**.

<ul style="margin-left:20px">
<li><strong>Destiny</strong> - <span>This is the most influential number in relation to your personal motivations, what and who you like in your surroundings, and the career(s) you would be most likely to aspire toward.
</span><br/><br/>

<li><strong>Personality</strong>
- <span>This number describes the behind-the-scenes or private you.
</span><br/><br/>

<li><strong>Attitude</strong>
- <span>This number is most powerful in the first 30-35 years of your life and represents the how and why you react to circumstances in your youth.
</span><br/><br/>
</ul>

 Your **Character**, **Soul Urge**, and **Hidden Agenda** derive from your **full name**.

<div style="padding-left:20px">
<ul>

<li><strong>Character</strong>
- <span>
This number represents primarily your public and social qualities, but you would also exhibit much of the same in your personal relations, too.
</span><br/><br/>

<li><strong>Soul Urge</strong>
- <span>
This influence presents a view of your intuitive, soulful self.
</span><br/><br/>

<li><strong>Hidden Agenda</strong>
- <span>
This vibration offers your innate (hidden) desires.
</span><br/><br/>

</div>


With your
**Destiny** and **Character** we determine your **Divine Purpose**.

<div style="padding-left:20px">
<ul>
<li><strong>Divine Purpose</strong>
- <span>
This is your farewell-performance number vibration. It is what your Soulful Self has chosen to achieve in your latter years of life.

</span>

 </div>

Check out [your numerology numbers](https://evoluteur.github.io/motivational-numerology/).


## Examples

Let's look at the numbers of some famous actors:

[Keanu Reeves](https://evoluteur.github.io/motivational-numerology/?name=Keanu+Charles+Reeves&month=9&day=2&year=1964),
[Matt Damon](https://evoluteur.github.io/motivational-numerology/?name=Matthew+Paige+Damon&month=8&day=8&year=1970),
[Anthony Hopkins](https://evoluteur.github.io/motivational-numerology/?name=Philip+Anthony+Hopkins&month=12&day=31&year=1937),
[Julia Roberts](https://evoluteur.github.io/motivational-numerology/?name=Julia+Fiona+Roberts&month=10&day=28&year=1967),
[Jack Nicholson](https://evoluteur.github.io/motivational-numerology/?name=John+Joseph+Nicholson&month=4&day=22&year=1937),
[Johnny Depp](https://evoluteur.github.io/motivational-numerology/?name=John+Christopher+Depp+II&month=6&day=9&year=1963),
[Sandra Bullock](https://evoluteur.github.io/motivational-numerology/?name=Sandra+Annette+Bullock&month=7&day=26&year=1964),
[Brad Pitt](https://evoluteur.github.io/motivational-numerology/?name=William+Bradley+Pitt&month=12&day=18&year=1963),
[Morgan Freeman](https://evoluteur.github.io/motivational-numerology/?name=Morgan+Freeman&month=6&day=1&year=1937),
[Leonardo DiCaprio](https://evoluteur.github.io/motivational-numerology/?name=Leonardo+Wilhelm+DiCaprio&month=11&day=11&year=1974),
[Robert De Niro](https://evoluteur.github.io/motivational-numerology/?name=Robert+Anthony+De+Niro+Jr.&month=8&day=17&year=1943),
[Robin Williams](https://evoluteur.github.io/motivational-numerology/?name=Robin+McLaurin+Williams&month=7&day=21&year=1951),
[Angelina Jolie](https://evoluteur.github.io/motivational-numerology/?name=Angelina+Jolie+Voight&month=6&day=4&year=1975)
[Will Smith](https://evoluteur.github.io/motivational-numerology/?name=Willard+Carroll+Smith+Jr.&month=9&day=25&year=1968)...


## Localization

Motivational-Numerology is available in <img src="https://evoluteur.github.io/motivational-numerology/pix/en.gif" style="margin:0 5px;"/>[English](https://evoluteur.github.io/motivational-numerology/)
<img src="https://evoluteur.github.io/motivational-numerology/pix/es.gif" style="margin:0 5px;"/> [Spanish](https://evoluteur.github.io/motivational-numerology/index-spanish.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/fr.gif" style="margin:0 5px;"/> [French](https://evoluteur.github.io/motivational-numerology/index-french.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/de.gif" style="margin:0 5px;"/> [German](https://evoluteur.github.io/motivational-numerology/index-german.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/pt.gif" style="margin:0 5px;"/> [Portuguese](https://evoluteur.github.io/motivational-numerology/index-portuguese.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/it.gif" style="margin:0 5px;"/> [Italian](https://evoluteur.github.io/motivational-numerology/index-italian.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/nl.gif" style="margin:0 5px;"/> [Dutch](https://evoluteur.github.io/motivational-numerology/index-dutch.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/jp.gif" style="margin:0 5px;"/> [Japanese](https://evoluteur.github.io/motivational-numerology/index-japanese.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/tr.gif" style="margin:0 5px;"/> [Turkish](https://evoluteur.github.io/motivational-numerology/index-turkish.html) 
<img src="https://evoluteur.github.io/motivational-numerology/pix/id.gif" style="margin:0 5px;"/> [Indonesian](https://evoluteur.github.io/motivational-numerology/index-indonesian.html).

Please feel free to contribute by submitting a [Pull Request](https://github.com/evoluteur/motivational-numerology/pulls) to support new languages.

## Code

The [code](https://github.com/evoluteur/motivational-numerology) is based on the book [Motivational Numerology](https://www.amazon.com/Motivational-Numerology-Numbers-Affect-Your/dp/0929765974) by [Sally Faubion](http://sallysnumbers.com/).

[<svg height="32" aria-hidden="true" viewBox="0 0 16 16" version="1.1" width="32" data-view-component="true" class="octicon octicon-mark-github v-align-middle color-fg-default">
    <path d="M8 0c4.42 0 8 3.58 8 8a8.013 8.013 0 0 1-5.45 7.59c-.4.08-.55-.17-.55-.38 0-.27.01-1.13.01-2.2 0-.75-.25-1.23-.54-1.48 1.78-.2 3.65-.88 3.65-3.95 0-.88-.31-1.59-.82-2.15.08-.2.36-1.02-.08-2.12 0 0-.67-.22-2.2.82-.64-.18-1.32-.27-2-.27-.68 0-1.36.09-2 .27-1.53-1.03-2.2-.82-2.2-.82-.44 1.1-.16 1.92-.08 2.12-.51.56-.82 1.28-.82 2.15 0 3.06 1.86 3.75 3.64 3.95-.23.2-.44.55-.51 1.07-.46.21-1.61.55-2.33-.66-.15-.24-.6-.83-1.23-.82-.67.01-.27.38.01.53.34.19.73.9.82 1.13.16.45.68 1.31 2.69.94 0 .67.01 1.3.01 1.49 0 .21-.15.45-.55.38A7.995 7.995 0 0 1 0 8c0-4.42 3.58-8 8-8Z"></path>
</svg>](https://github.com/evoluteur/motivational-numerology) Motivational-Numerology is Open Source and hosted on [GitHub](https://github.com/evoluteur/motivational-numerology).

Contribute to Motivational-Numerology:

<ul>
<li>
<a href="https://github.com/evoluteur/motivational-numerology//labels/bug">Report a Bug</a>
</li>
<li><a href="https://github.com/evoluteur/motivational-numerology/labels/enhancement">Propose a Feature Request</a>
</li>
<li><a href="https://github.com/evoluteur/motivational-numerology/pulls">Submit a Pull Request</a>
</li>
</ul>


(c) 2024 [Sally Faubion](http://sallysnumbers.com/) & [Olivier Giulieri](https://evoluteur.github.io/).

==> motivational-numerology-2.3.3.tgz: package/README.md <==
# Motivational-Numerology [![npm version](https://img.shields.io/npm/v/motivational-numerology)](https://www.npmjs.com/package/motivational-numerology)

Motivational-Numerology is a web page to calculate the numerology numbers derived from your name and birth date and get a brief interpretation by [Sally Faubion](http://sallysnumbers.com/).

Check out [your numerology star](https://evoluteur.github.io/motivational-numerology/).

[![Star](https://raw.githubusercontent.com/evoluteur/motivational-numerology/master/pix/numerology-star-labels.gif)](https://evoluteur.github.io/motivational-numerology/)

To better understand your personal numerology numbers and go deeper in their interpretation, [book a private phone reading](https://sallysnumbers.com/services/) with Sally Faubion.

## Numerology Numbers

Your numerology numbers are calculated based on your birthdate and your full name.

Your **Destiny**, **Personality**, and **Attitude** derive from your **birth date**.

<ul style="margin-left:20px">
<li><strong>Destiny</strong> - <span>This is the most influential number in relation to your personal motivations, what and who you like in your surroundings, and the career(s) you would be most likely to aspire toward.
</span><br/><br/>

<li><strong>Personality</strong>
- <span>This number describes the behind-the-scenes or private you.
</span><br/><br/>

<li><strong>Attitude</strong>
- <span>This number is most powerful in the first 30-35 years of your life and represents the how and why you react to circumstances in your youth.
</span><br/><br/>
</ul>

 Your **Character**, **Soul Urge**, and **Hidden Agenda** derive from your **full name**.

<div style="padding-left:20px">
<ul>

<li><strong>Character</strong>
- <span>
This number represents primarily your public and social qualities, but you would also exhibit much of the same in your personal relations, too.
</span><br/><br/>

<li><strong>Soul Urge</strong>
- <span>
This influence presents a view of your intuitive, soulful self.
</span><br/><br/>

<li><strong>Hidden Agenda</strong>
- <span>
This vibration offers your innate (hidden) desires.
</span><br/><br/>

</div>


With your
**Destiny** and **Character** we determine your **Divine Purpose**.

<div style="padding-left:20px">
<ul>
<li><strong>Divine Purpose</strong>
- <span>
This is your farewell-performance number vibration. It is what your Soulful Self has chosen to achieve in your latter years of life.

</span>

 </div>

Check out [your numerology numbers](https://evoluteur.github.io/motivational-numerology/).


## Examples

Let's look at the numbers of a few famous actors:

[Keanu Reeves](https://evoluteur.github.io/motivational-numerology/?name=Keanu+Charles+Reeves&month=9&day=2&year=1964),
[Samuel L. Jackson](https://evoluteur.github.io/motivational-numerology/?name=Samuel+Leroy+Jackson&month=12&day=21&year=1948),
[Denzel Washington](https://evoluteur.github.io/motivational-numerology/?name=Denzel+Hayes+Washington+Junior&month=12&day=28&year=1954),
[Tom Hanks](https://evoluteur.github.io/motivational-numerology/?name=Thomas+Jeffrey+Hanks&month=7&day=9&year=1956),
[Matt Damon](https://evoluteur.github.io/motivational-numerology/?name=Matthew+Paige+Damon&month=8&day=8&year=1970),
[Anthony Hopkins](https://evoluteur.github.io/motivational-numerology/?name=Philip+Anthony+Hopkins&month=12&day=31&year=1937),
[Julia Roberts](https://evoluteur.github.io/motivational-numerology/?name=Julia+Fiona+Roberts&month=10&day=28&year=1967),
[Hugh Jackman](https://evoluteur.github.io/motivational-numerology/?name=Hugh+Michael+Jackman+AC&month=10&day=12&year=1968),
[Jamie Lee Curtis](https://evoluteur.github.io/motivational-numerology/?name=Jamie+Lee+Curtis&month=11&day=22&year=1958),
[Jack Nicholson](https://evoluteur.github.io/motivational-numerology/?name=John+Joseph+Nicholson&month=4&day=22&year=1937),
[Johnny Depp](https://evoluteur.github.io/motivational-numerology/?name=John+Christopher+Depp+II&month=6&day=9&year=1963),
[Sandra Bullock](https://evoluteur.github.io/motivational-numerology/?name=Sandra+Annette+Bullock&month=7&day=26&year=1964),
[Brad Pitt](https://evoluteur.github.io/motivational-numerology/?name=William+Bradley+Pitt&month=12&day=18&year=1963),
[Angelina Jolie](https://evoluteur.github.io/motivational-numerology/?name=Angelina+Jolie+Voight&month=6&day=4&year=1975),
[Morgan Freeman](https://evoluteur.github.io/motivational-numerology/?name=Morgan+Freeman&month=6&day=1&year=1937),
[Leonardo DiCaprio](https://evoluteur.github.io/motivational-numerology/?name=Leonardo+Wilhelm+DiCaprio&month=11&day=11&year=1974),
[Robert De Niro](https://evoluteur.github.io/motivational-numerology/?name=Robert+Anthony+De+Niro+Jr.&month=8&day=17&year=1943),
[Robin Williams](https://evoluteur.github.io/motivational-numerology/?name=Robin+McLaurin+Williams&month=7&day=21&year=1951),
[Will Smith](https://evoluteur.github.io/motivational-numerology/?name=Willard+Carroll+Smith+Jr.&month=9&day=25&year=1968),
[Danny DeVito](https://evoluteur.github.io/motivational-numerology/?name=Daniel+Michael+DeVito+Jr.&month=11&day=17&year=1944),
[Nicolas Cage](https://evoluteur.github.io/motivational-numerology/?name=Nicolas+Kim+Coppola&month=1&day=7&year=1964)...

Like in the above examples, you can use the url parameters "name", "month", "day", "year" to set the values on the numerology page.

## Localization

Motivational-Numerology is available in <img src="https://evoluteur.github.io/motivational-numerology/pix/en.gif" style="margin:0 5px;"/> [English](https://evoluteur.github.io/motivational-numerology/)
<img src="https://evoluteur.github.io/motivational-numerology/pix/es.gif" style="margin:0 5px;"/> [Spanish](https://evoluteur.github.io/motivational-numerology/index-spanish.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/fr.gif" style="margin:0 5px;"/> [French](https://evoluteur.github.io/motivational-numerology/index-french.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/de.gif" style="margin:0 5px;"/> [German](https://evoluteur.github.io/motivational-numerology/index-german.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/pt.gif" style="margin:0 5px;"/> [Portuguese](https://evoluteur.github.io/motivational-numerology/index-portuguese.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/it.gif" style="margin:0 5px;"/> [Italian](https://evoluteur.github.io/motivational-numerology/index-italian.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/nl.gif" style="margin:0 5px;"/> [Dutch](https://evoluteur.github.io/motivational-numerology/index-dutch.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/jp.gif" style="margin:0 5px;"/> [Japanese](https://evoluteur.github.io/motivational-numerology/index-japanese.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/tr.gif" style="margin:0 5px;"/> [Turkish](https://evoluteur.github.io/motivational-numerology/index-turkish.html)
<img src="https://evoluteur.github.io/motivational-numerology/pix/id.gif" style="margin:0 5px;"/> [Indonesian](https://evoluteur.github.io/motivational-numerology/index-indonesian.html).

For each language an HTML page "index-&lt;language&gt;.html" and a Javascript object with translated strings "/i18n/meaning_&lt;languageId&gt;.js".

Please feel free to contribute by submitting a [Pull Request](https://github.com/evoluteur/motivational-numerology/pulls) to support new languages.

## Code

The [code](https://github.com/evoluteur/motivational-numerology) is based on the book [Motivational Numerology](https://www.amazon.com/Motivational-Numerology-Numbers-Affect-Your/dp/0929765974) by [Sally Faubion](http://sallysnumbers.com/).

To learn more about your numerology numbers and they mean for you, [book a personal reading with Sally Faubion](https://sallysnumbers.com/services/).


[Motivational-Numerology](https://github.com/evoluteur/motivational-numerology)  is Open Source at [GitHub](https://github.com/evoluteur/motivational-numerology) with AGPLv3 license.

Contribute to Motivational-Numerology:

- [Report a Bug](https://github.com/evoluteur/motivational-numerology/labels/bug)
- [Propose a Feature Request](https://github.com/evoluteur/motivational-numerology/labels/enhancement)
- [Submit a Pull Request](https://github.com/evoluteur/motivational-numerology/pulls)

(c) 2024 [Sally Faubion](http://sallysnumbers.com/) & [Olivier Giulieri](https://evoluteur.github.io/).
